SystemOrganization addCategory: #ConfigurationOfSwaLint!

Object subclass: #ConfigurationOfSwaLint
	instanceVariableNames: 'project storedDeprecationSetting'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSwaLint'!

!ConfigurationOfSwaLint class methodsFor: 'private' stamp: 'topa 4/23/2010 14:48'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSwaLint class methodsFor: 'private' stamp: 'topa 4/23/2010 14:48'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfSwaLint class methodsFor: 'metacello tool support' stamp: 'topa 4/23/2010 14:48'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSwaLint class methodsFor: 'metacello tool support' stamp: 'topa 4/23/2010 14:48'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSwaLint class methodsFor: 'loading' stamp: 'mt 2/11/2012 13:47:33.048'!
load
	"self load"

	^ (self project version: #stable) load! !

!ConfigurationOfSwaLint class methodsFor: 'loading' stamp: 'mt 2/11/2012 13:47:46.443'!
loadDevelopment
	"self loadDevelopment"

	^ (self project version: #development) load! !

!ConfigurationOfSwaLint class methodsFor: 'metacello tool support' stamp: 'topa 4/23/2010 14:48'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSwaLint class methodsFor: 'accessing' stamp: 'topa 4/23/2010 14:48'!
project

	^self new project! !

!ConfigurationOfSwaLint class methodsFor: 'unloading Metacello' stamp: 'topa 4/23/2010 14:48'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfSwaLint methodsFor: 'baselines' stamp: 'topa 4/23/2010 16:55'!
baseline200: spec 
	<version: '2.0.0-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://www.squeaksource.com/SwaLint';
			description: 'Initial Baseline for SwaLint 2';
			postLoadDoIt: #postLoadFor200.
		"Requirements"	
		spec
			package: 'AST-Core' with: [spec
				repository: 'http://www.squeaksource.com/rb'];
			package: 'Refactoring-Core' with: [spec 
				requires: 'AST-Core';
				repository: 'http://www.squeaksource.com/rb'].
		spec 
			package: 'SwaLint-Core' with: [spec requires: #('AST-Core' 'Refactoring-Core')]; 
			package: 'SwaLint-PlugIns' with: [ spec requires: 'SwaLint-Core' ];
			package: 'SwaLint-Tests' with: [ spec requires: #('SwaLint-Core' 'SwaLint-PlugIns') ].
		spec
			group: 'default' with: #('PlugIns');
			group: 'Core' with: #('SwaLint-Core');
			group: 'PlugIns' with: #('SwaLint-PlugIns');
			group: 'Tests' with: #('SwaLint-Tests')].
	spec for: #pharo do: [
		spec 
			preLoadDoIt: #preLoadPharo200;
			postLoadDoIt: #postLoadPharo200].! !

!ConfigurationOfSwaLint methodsFor: 'baselines' stamp: 'tfel 4/11/2011 08:48:19.05'!
baseline203: spec 
	<version: '2.0.3-baseline'>
	
	spec for: #common do: [
		spec
			blessing: #baseline;
			repository: 'http://www.squeaksource.com/SwaLint';
			description: 'Initial Baseline for SwaLint 2';
			postLoadDoIt: #postLoadFor200.
		"Requirements"
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'SwaLint-Core' with: [spec requires: #('Refactoring-Core')]; 
			package: 'SwaLint-PlugIns' with: [ spec requires: 'SwaLint-Core' ];
			package: 'SwaLint-Tests' with: [ spec requires: #('SwaLint-Core' 'SwaLint-PlugIns') ].
		spec
			group: 'default' with: #('SwaLint-PlugIns');
			group: 'Core' with: #('SwaLint-Core');
			group: 'PlugIns' with: #('SwaLint-PlugIns');
			group: 'Tests' with: #('SwaLint-Tests')].
	spec for: #pharo do: [
		spec 
			preLoadDoIt: #preLoadPharo200;
			postLoadDoIt: #postLoadPharo200].! !

!ConfigurationOfSwaLint methodsFor: 'symbolic versions' stamp: 'mt 2/11/2012 13:45:11.739'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '2.0.5'.
! !

!ConfigurationOfSwaLint methodsFor: 'doits' stamp: 'topa 4/23/2010 16:37'!
postLoadFor200

	(((Smalltalk respondsTo: #globals) 
		ifTrue: [Smalltalk globals] "Squeak >=4.1"
		ifFalse: [Smalltalk]) "Pharo and squeak <=4.0"
		at: #SwaLint) perform: #hardReset.! !

!ConfigurationOfSwaLint methodsFor: 'doits' stamp: 'topa 4/23/2010 16:50'!
postLoadPharo200

	self postLoadFor200.
	Preferences setPreference: #raiseDeprecatedWarnings toValue: self storedDeprecationSetting.
	
! !

!ConfigurationOfSwaLint methodsFor: 'doits' stamp: 'topa 4/23/2010 17:04'!
preLoadPharo200

	self storedDeprecationSetting: (Preferences valueOfPreference: #raiseDeprecatedWarnings).
	Preferences setPreference: #raiseDeprecatedWarnings toValue: false.
	! !

!ConfigurationOfSwaLint methodsFor: 'accessing' stamp: 'topa 4/23/2010 14:48'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSwaLint methodsFor: 'symbolic versions' stamp: 'tfel 7/22/2011 12:20:37.656'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'squeakCommon' version: '2.0.3'.
! !

!ConfigurationOfSwaLint methodsFor: 'accessing' stamp: 'topa 4/23/2010 16:50'!
storedDeprecationSetting
	
	^ storedDeprecationSetting! !

!ConfigurationOfSwaLint methodsFor: 'accessing' stamp: 'topa 4/23/2010 16:50'!
storedDeprecationSetting: anObject
	
	storedDeprecationSetting := anObject! !

!ConfigurationOfSwaLint methodsFor: 'versions' stamp: 'tfel 7/22/2011 12:21:25.19'!
version203: spec 
	<version: '2.0.3' imports: #('2.0.3-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec 
			project: 'Refactoring-Core' with: #stable;
			package: 'SwaLint-Core' with: 'SwaLint-Core-tfel.5';
			package: 'SwaLint-PlugIns' with: 'SwaLint-PlugIns-tfel.4';
			package: 'SwaLint-Tests' with: 'SwaLint-Tests-topa.2'].! !

!ConfigurationOfSwaLint methodsFor: 'versions' stamp: 'tfel 7/22/2011 12:22:06.022'!
version204: spec
	<version: '2.0.4' imports: #('2.0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '2.0.4 (): Bump'.
		spec author: 'tfel'.
		spec timestamp: '7/22/2011 12:22'.
		spec project: 'Refactoring-Core' with: '1.7'.
		spec 
			package: 'SwaLint-Core' with: 'SwaLint-Core-tfel.5';
			package: 'SwaLint-PlugIns' with: 'SwaLint-PlugIns-tfel.6';
			package: 'SwaLint-Tests' with: 'SwaLint-Tests-topa.2'. ].
! !

!ConfigurationOfSwaLint methodsFor: 'versions' stamp: 'mt 2/11/2012 13:44:55.262'!
version205: spec
	<version: '2.0.5' imports: #('2.0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #development.
		spec description: 'This is the current trunk version.'.
		spec author: 'Marcel Taeumel'.

		spec project: 'Refactoring-Core' with: '1.7'].
! !
